test/jdk/java/net/httpclient/CustomRequestPublisher.java
branchhttp-client-branch
changeset 56089 42208b2f224e
parent 48083 b1c1b4ef4be2
child 56092 fd85b2bf2b0d
--- a/test/jdk/java/net/httpclient/CustomRequestPublisher.java	Tue Feb 06 19:37:56 2018 +0000
+++ b/test/jdk/java/net/httpclient/CustomRequestPublisher.java	Wed Feb 07 14:17:24 2018 +0000
@@ -25,9 +25,9 @@
  * @test
  * @summary Checks correct handling of Publishers that call onComplete without demand
  * @modules java.base/sun.net.www.http
  *          jdk.incubator.httpclient/jdk.incubator.http.internal.common
  *          jdk.incubator.httpclient/jdk.incubator.http.internal.frame
  *          jdk.incubator.httpclient/jdk.incubator.http.internal.hpack
  *          java.logging
  *          jdk.httpserver
  * @library /lib/testlibrary http2/server
@@ -56,9 +56,9 @@
 import java.util.function.Supplier;
 import java.util.stream.Collectors;
 import javax.net.ssl.SSLContext;
-import jdk.incubator.http.HttpClient;
-import jdk.incubator.http.HttpRequest;
-import jdk.incubator.http.HttpResponse;
+import java.net.http.HttpClient;
+import java.net.http.HttpRequest;
+import java.net.http.HttpResponse;
 import jdk.testlibrary.SimpleSSLContext;
 import org.testng.annotations.AfterTest;
 import org.testng.annotations.BeforeTest;
@@ -66,7 +66,7 @@
 import org.testng.annotations.Test;
 import static java.lang.System.out;
 import static java.nio.charset.StandardCharsets.US_ASCII;
-import static jdk.incubator.http.HttpResponse.BodyHandler.asString;
+import static java.net.http.HttpResponse.BodyHandler.asString;
 import static org.testng.Assert.assertEquals;
 import static org.testng.Assert.assertTrue;
@@ -25,9 +25,9 @@
  * @summary Checks correct handling of Publishers that call onComplete without demand
  * @modules java.base/sun.net.www.http
- *          jdk.incubator.httpclient/jdk.incubator.http.internal.common
- *          jdk.incubator.httpclient/jdk.incubator.http.internal.frame
- *          jdk.incubator.httpclient/jdk.incubator.http.internal.hpack
+ *          java.net.http/java.net.http.internal.common
+ *          java.net.http/java.net.http.internal.frame
+ *          java.net.http/java.net.http.internal.hpack
  *          java.logging
  *          jdk.httpserver